/********************************************************************************
 System Setup Define Section
 
 Comment out (please don't delete) the ones that do not apply to your code
********************************************************************************/


/*****************************************************************************
 Symbolic constants / definitions
******************************************************************************/


/********************************************************************************************
* The following option is always required, if SDRAM memory is required:                     *
*           #define SDRAM_SIZE xy       Available options for xy are:                       *
*                                       128 --> SDRAM memory size = 128MB                   *
*                                        64 --> SDRAM memory size =  64MB                   *
*                                        32 --> SDRAM memory size =  32MB                   *
*                                        16 --> SDRAM memory size =  16MB                   *
*                                         8 --> SDRAM memory size =   8MB                   *
*                                       Use this option whenever SDRAM is used, regardless, *
*                                       if startup code, init code or the emulator are      *
*                                       initializing SDRAM                                  *
*                                       Activates some functions in system.asm              *
*           #define EN_SDRAM            --> Enable SDR-SDRAM memory or DDR-SDRAM            *
*                                       in bfstartup.asm                                    *
*                                       usually NOT required as long as either              *
*                                       VDSP++/Emulator or init code is doing this          *
*           #define EN_ASYNC_MEM        --> Enable asynchronous memory                      *
*           #define SET_PLL             --> Change default (reset) PLL and                  *
*                                       voltage controller settings                         *
*           #define LIMIT15kB           Memory W/R is will be limited to 15kB of SDRAM      *
*           #define USE_LDF_RESOLVE     include 'LDF_RESOLVE.h' in the LDF file             *
*           #define __EZKITLITE__       platform is an EZ-KIT Lite                          *
********************************************************************************************/

#define             SDRAM_SIZE      64
//#define             EN_SDRAM

//#define             EN_ASYNC_MEM

//#define             SET_PLL

//#define             LIMIT15kB

#define             USE_LDF_RESOLVE

#define             __EZKITLITE__


/************************************************************
* Otherwise code is run in supervisor mode ISR15 by default *
************************************************************/

//#define             RUN_USER


/********************************************************************************************************************
* Define which cache-setup to use.                                                                                  *
* Available options are:                                                                                            *
*           #define INSTR_CACHE_EN      --> enable instruction cache                                                *
*                                                                                                                   *
*           #define DATA_CACHE_EN       --> enable data cache                                                       *
*           #define DATA_CACHE_DCBS     --> DCBS = 1: A[23] is used to select Data Bank A or Data Bank B            *
*                                           only valid if DATA_CACHE_AB is defined                                  *
*                                           DCBS = 0: A[14] is used to select Data Bank A or Data Bank B (default)  *
*           #define DATA_CACHE_AB       --> use both, Data Bank A+B for Data Cache                                  *
*                                           use Data Bank A only for Data Cache (default)                           *
*           #define DATA_CACHE_WT       --> CPLB_WT = 1: enable data-write-through                                  *
*                                           CPLB_WT = 0: enable data-write-back (default)                           *
*           #define DATA_CACHE_AOW      --> CPLB_L1_AOW = 1: Allocate cache lines on reads and writes               *
*                                           valid only if write through cacheable                                   *
*                                           CPLB_L1_AOW = 0: Allocate cache lines on reads only (default)           *
* Hint:     IVG14 is dedicated to the xCPLB exception handler !!!                                                   *
********************************************************************************************************************/

//#define         INSTR_CACHE_EN
                                            /* if enabling instruction cache and run system by emulator,
                                               than comment out EN_SDRAM and use XML reset values.
                                               There are some functions mapped into external memory */

#define         DATA_CACHE_EN
//#define         DATA_CACHE_DCBS
//#define         DATA_CACHE_AB
//#define         DATA_CACHE_WT
//#define         DATA_CACHE_AOW


/************************************************************************************************************
* Definitions for Memory Tests                                                                              *
* Available options are:                                                                                    *
* Available Tests are:                                                                                      *
*           #define __ICACHETEST__      -->     enables the instruction cache test                          *
*           #define __DCACHETEST__      -->     enables the data cache test                                 *
************************************************************************************************************/

//#define __ICACHETEST__
#define __DCACHETEST__


/**************************************
* don't modify the following cleanups *
**************************************/

#if !defined DATA_CACHE_EN
    #undef      DATA_CACHE_DCBS
    #undef      DATA_CACHE_AB
    #undef      DATA_CACHE_WT
    #undef      DATA_CACHE_AOW
#endif

#if defined __ADSPBF531__
    #undef      DATA_CACHE_DCBS
    #undef      DATA_CACHE_AB
#endif

#if defined LIMIT15kB
    #define     LIMIT32kB
#endif


/*****************************************************************************
 EOF
******************************************************************************/
