/************************************************************************
*                                                                       *
* ncplb.h                                                               *
*                                                                       *
* (c) Copyright 2008-2009 Analog Devices, Inc.  All rights reserved.    *
*                                                                       *
************************************************************************/

/* L1 Instruction Memory Control Register (IMEM_CONTROL) */
#define CPLB_DISABLE_ICPLBS 0x0 /* Instruction CPLB enable: CLPBs disabled, minimal address checking only */
#define nIMC                0x0 /* Enable/Disable Instruction Cache functionality: Upper 16K byte of LI instruction memory configured as SRAM, also invalidates all cache lines if previously configured as cache */
#define nILOC               0x0 /* Way not locked */
#define nLRUPRIORST         0x0 /* LRU priority functionality is enabled */


/* ICPLB Data Registers (ICPLB_DATAx) */
#define nCPLB_LRUPRIO       0x0 /* LRUPRIORST in IMEM_CONTROL: Low importance */
#define nCPLB_L1_CHBL       0x0 /* Clear this bit whenever L1 memory is configured as SRAM: Non-cacheable in L1 */


/* L1 Data Memory Control Register (DMEM_CONTROL) */
#define CPLB_DISABLE_DCPLBS 0x0 /* Data CPLB enable: CLPBs disabled, minimal address checking only */
#define nCPLB_DCBS          0x0 /* L1 Data Cache Bank Select: A[14] (16kB switch) */
#define nPORT_PREF0         0x0 /* DAG0 Port Preference: DAG0 non-cacheable fetches use port A */
#define nPORT_PREF1         0x0 /* DAG1 Port Preference: DAG1 non-cacheable fetches use port A */

/* DCPLB Data Registers (DCPLB_DATAx) */
#define nCPLB_USER_WR       0x0 /* User mode write access generates protection violation exception */
#define nCPLB_SUPV_WR       0x0 /* Supervisor mode write access generates protection violation exception */
#define CPLB_CLEAN          0x0 /* Clean. Valid only if write back cacheable (CPLB_VALID = 1, CPLB_WT = 0, and CPLB_L1_CHBL = 1) */
#define nCPLB_L1_CHBL       0x0 /* Clear this bit whenever L1 memory is configured as SRAM: Non-cacheable in L1 */
#define CPLB_WB             0x0 /* Operates only in cache mode: Write back */
#define nCPLB_L1_AOW        0x0 /* Valid only if write through cacheable (CPLB_VALID = 1, CPLB_WT = 1): Allocate cache lines on reads only */
#define nCPLB_MEM_LEV       0x0 /* ADSP-BF561 only. Determines line fill and write buffers. High priority (usually best for on-chip L2 memory pages) */


/* xCPLB Data Registers (ICPLB_DATAx / DCPLB_DATAx) */
#define nCPLB_USER_RD       0x0 /* User mode read access generates protection violation exception */
#define CPLB_INVALID        0x0 /* Invalid (disabled) CPLB entry */
#define CPLB_UNLOCK         0x0 /* Can be used by software in CPLB replacement algorithms: Unlocked, CPLB entry can be replaced */


/****************************************************************************
 EOF
*****************************************************************************/
